==> eightyfs-0.10.1-sources.jar: de/pfabulist/lindwurm/eighty/attributes/RWAttributes.java <==
package de.pfabulist.lindwurm.eighty.attributes;

import java.nio.file.attribute.BasicFileAttributes;
import java.nio.file.attribute.FileAttributeView;
import java.util.Set;

/**
 * ** BEGIN LICENSE BLOCK *****
 * BSD License (2 clause)
 * Copyright (c) 2006 - 2015, Stephan Pfab
 * All rights reserved.
 * <p>
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * <p>
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL Stephan Pfab BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * **** END LICENSE BLOCK ****
 */

public abstract class RWAttributes {

    private final String viewName;
    private final Class<FileAttributeView> viewType;
    private final Class<BasicFileAttributes> readType;

    protected RWAttributes( String viewName, Class<FileAttributeView> viewType, Class<BasicFileAttributes> readType ) {
        this.viewName = viewName;
        this.viewType = viewType;
        this.readType = readType;
    }

    protected RWAttributes( String viewName, Class<FileAttributeView> viewType ) {
        this.viewName = viewName;
        this.viewType = viewType;
        this.readType = null;
    }

    public String getViewName() {
        return viewName;
    }

    public abstract Object read( FileAttributeView view, String attiName );

    public abstract Set<String> getAttributeNames();

    public Class<FileAttributeView> getViewType() {
        return viewType;
    }

    public abstract void set( FileAttributeView view, String next, Object value );

    public abstract boolean isSettable( String attiName );
}

==> eightyfs-0.10.3-sources.jar: de/pfabulist/lindwurm/eighty/attributes/RWAttributes.java <==
package de.pfabulist.lindwurm.eighty.attributes;

import java.nio.file.attribute.BasicFileAttributes;
import java.nio.file.attribute.FileAttributeView;
import java.util.Set;

/**
 * ** BEGIN LICENSE BLOCK *****
 * BSD License (2 clause)
 * Copyright (c) 2006 - 2015, Stephan Pfab
 * All rights reserved.
 * <p>
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * <p>
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL Stephan Pfab BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * **** END LICENSE BLOCK ****
 */

public abstract class RWAttributes {

    private final String viewName;
    private final Class<FileAttributeView> viewType;

//    protected RWAttributes( String viewName, Class<FileAttributeView> viewType, Class<BasicFileAttributes> readType ) {
//        this.viewName = viewName;
//        this.viewType = viewType;
//    }

    protected RWAttributes( String viewName, Class<FileAttributeView> viewType ) {
        this.viewName = viewName;
        this.viewType = viewType;
    }

    public String getViewName() {
        return viewName;
    }

    public abstract Object read( FileAttributeView view, String attiName );

    public abstract Set<String> getAttributeNames();

    public Class<FileAttributeView> getViewType() {
        return viewType;
    }

    public abstract void set( FileAttributeView view, String next, Object value );

    public abstract boolean isSettable( String attiName );
}
